#
# spec file for package rpmconf
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rpmconf
Version:        1.1.10
Release:        1.3
Summary:        Tool to handle rpmnew and rpmsave files
License:        GPL-3.0-or-later
URL:            https://github.com/xsuchy/rpmconf
Source:         https://github.com/xsuchy/%{name}/archive/%{name}-%{version}-1.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  docbook-utils-minimal
BuildRequires:  docbook_3
BuildRequires:  fdupes
BuildRequires:  make
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Sphinx
BuildRequires:  python3-devel
BuildRequires:  python3-rpm
Requires:       python3-%{name}
Requires:       python3-rpm
Suggests:       diffuse
Suggests:       diffutils
Suggests:       kdiff3
Suggests:       meld
Suggests:       vim
BuildArch:      noarch

%description
This tool search for .rpmnew, .rpmsave and .rpmorig files and ask
you what to do with them:
Keep current version, place back old version, watch the diff or merge.

%package -n python3-%{name}
Summary:        Python interface for rpmconf
Group:          Development/Languages/Python

%description -n python3-%{name}
Python interface for rpmconf and an essential part of rpmconf.

%prep
%autosetup -n %{name}-%{name}-%{version}-1

sed -i 's/__version__ = .*/__version__ = "%{version}"/' rpmconf/rpmconf.py
sed -i 's/version = .*,/version = "%{version}",/' setup.py

%build
%python3_build
docbook2man %{name}.sgml
%make_build -C docs man \
  SPHINXBUILD=sphinx-build-%{py3_ver}

%install
%python3_install --skip-build --install-scripts %{_sbindir}

chmod a+x %{buildroot}%{python3_sitelib}/%{name}/%{name}.py
install -Dpm 0644 %{name}.8 %{buildroot}%{_mandir}/man8/%{name}.8
install -Dpm 0644 docs/build/man/%{name}.3 %{buildroot}%{_mandir}/man3/%{name}.3
mkdir -p %{buildroot}%{_datadir}/%{name}/
find docs/build/ -type f -name ".buildinfo" -delete -print

%fdupes -s %{buildroot}%{python3_sitelib}

%files
%license LICENSE
%doc README.md TODO
%{_sbindir}/%{name}
%dir %{_datadir}/%{name}/
%{_mandir}/man8/%{name}.8%{?ext_man}

%files -n python3-%{name}
%license LICENSE
%doc README.md TODO
%{python3_sitelib}/%{name}/
%{python3_sitelib}/%{name}-*
%{_mandir}/man3/%{name}.3%{?ext_man}

%changelog
* Sun Jan 28 2024 Dirk Müller <dmueller@suse.com>
- update to 1.1.10:
  * Use rpm.files instead of rpm.fi
  * Add upper version bound for setInterruptSafety()
* Thu Oct 19 2023 Daniel Garcia Moreno <daniel.garcia@suse.com>
- Do not use break lines in %%python3_install macro to avoid problems
  with possible macro expansion. The option "--root %%{buildroot}" is
  not needed because it's in the macro by default.
  See gh#openSUSE/python-rpm-macros#164
* Thu Jun  8 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.1.9:
  * Add BuildRequire on setuptools to fix distutils error on
    Python 3.12
* Mon Dec  5 2022 Dirk Müller <dmueller@suse.com>
- update to 1.1.8:
  * change wording to avoid confusion
  * avoid loops during clean action
* Sat Nov 20 2021 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.1.4 (changes since 1.0.19):
  * Better handle message after merging.
  * Add sdiff support (gh#xsuchy/rpmconf#51).
  * rpmconf.sgml: Improve readability.
  * Drop the deprecated no-op "U" mode for open() for Python 3.9+.
  * Fix short version of --version.
  * Implement --root option.
  * initialise rpm transaction faster.
  * Do not traceback when Ctrl+C.
  * Do not go over all packages if neither -a or -o is set.
  * Implement --exclude.
  * Implement unattended mode.
  * Move init section after sleep() so it can be interrupted by ^C.
- Fix version in the released RPM.
- BuildRequire make.
* Tue May  9 2017 sor.alexei@meowr.ru
- Update to version 1.0.19:
  * Implement --test.
  * Correctly pass /dev/null to difflib (rh#1350249).
* Sat Jul 23 2016 sor.alexei@meowr.ru
- Update to version 1.0.18 (changes since 1.0.16):
  * Fix a typo in /usr/bin/ls call arguments.
  * Standard import "import errno" comes before
    "from rpmconf import rpmconf".
  * Set loglevel only for rpmconf logger.
  * Add pylintrc.
* Fri Dec  4 2015 sor.alexei@meowr.ru
- Update to 1.0.16:
  * Local variable 'fromdate' referenced before assignment.
* Sat Nov 28 2015 sor.alexei@meowr.ru
- Update to 1.0.15:
  * Handle broken symlinks.
* Wed Nov 25 2015 sor.alexei@meowr.ru
- Update to 1.0.14:
  * Improve error message.
  * Check for root privileges.
  * Clarify man page.
* Mon Nov 16 2015 sor.alexei@meowr.ru
- Update to 1.0.13:
  * Do TB when somebody remove file under our hand.
* Tue Aug 18 2015 sor.alexei@meowr.ru
- Remove python3-rpmconf-doc which contained a HTML page with the
  same content as does rpmconf (3) manpage.
  This also solves odd build failures.
* Sat Jul  4 2015 sor.alexei@meowr.ru
- Update to 1.0.12 (changes since 1.0.9):
  * Other method for stdin flush and handle Ctrl+C correctly.
  * Disable pylint warnings.
* Thu Jun  4 2015 sor.alexei@meowr.ru
- Update to 1.0.9 (changes since 1.0.7):
  * pylint: let the logger expand params.
  * 1226591 - do not flush stdin, when it is not TTY.
  * Use RPM Python API to get package name of file.
  * Minor fixes.
- Change group of python3-rpmconf-doc to Documentation/HTML.
- Suggest diffuse, kdiff3, meld, vim as mainstream does.
* Thu Jan 15 2015 sor.alexei@meowr.ru
- Update to 1.0.7:
  * Add / before usr/bin.
* Fri Jan  9 2015 sor.alexei@meowr.ru
- Update to 1.0.6 (changes since 1.0.4):
  * Let tito bump up version in docs/source/conf.py.
  * Split to python class and CLI.
  * Use rpm python api to get version.
* Mon Jan  5 2015 sor.alexei@meowr.ru
- Initial package.
